@@ -125,7 +125,7 @@ def publish_package(
 
     uv run python -m src publish-package --filename service_example --username n.shokurov --password test_pass
 
-    uv run datacontract-helper publish-package --filename service_example --username n.shokurov --password test_pass
+    uv run datacontract-helper publish-package --filename service_example --username n.shokurov --password test_pass --wheel-version 0.1.1
 
 
     """
@@ -148,12 +148,12 @@ def publish_package(
 @cli.command()
 @click.option("--filename", required=True)
 @click.option("--subject-name", required=True)
-@click.option("--version", required=True)
+# @click.option("--version")
 # @click.option("--compatibility-type", required=False)
 def validate_schema_registry(
     filename: str,
     subject_name: str,
-    version: str,
+    # version: str | None = None,
     # compatibility_type: str | None = None,
 ):
     """
@@ -162,10 +162,9 @@ def validate_schema_registry(
 
     uv run datacontract-helper validate-schema-registry --filename "et_admin_datacontract" --subject-name et_admin_datacontract
     """
-
     SchemaRegistryClient().validate_schema_registry(
         subject_name=subject_name,
-        version=version,
+        # version=version,
         filename=filename,
         # compatibility_type=compatibility_type,
     )
@@ -179,7 +178,7 @@ def publish_schema_registry(
     subject_name: str,
 ):
     """
-    uv run --env-file .env python -m src publish-schema-registry --filename "et_admin_datacontract" --subject-name et_admin_datacontract
+    uv run python -m src publish-schema-registry --filename "service_example" --subject-name "etl_scripts.logs-value"
 
     uv run datacontract-helper publish-schema-registry --filename et_admin_datacontract --subject-name et_admin_datacontract
 
@@ -187,3 +186,22 @@ def publish_schema_registry(
     SchemaRegistryClient().publish_schema_registry(
         filename=filename, subject_name=subject_name
     )
+
+
+@cli.command()
+@click.option("--filename", required=True)
+@click.option("--subject-name", required=True)
+def delete_schema_registry(
+    filename: str,
+    subject_name: str,
+):
+    """
+    uv run python -m src delete-schema-registry --filename "service_example" --subject-name service_example
+
+    uv run datacontract-helper delete-schema-registry --filename et_admin_datacontract --subject-name et_admin_datacontract
+
+    """
+    SchemaRegistryClient().delete_schema_registry(
+        filename=filename, subject_name=subject_name
+    )
+
