@@ -28,7 +28,7 @@ class ModuleBuilder:
         #     check=True,
         # )
 
-        result: subprocess.CompletedProcess = subprocess.run(
+        subprocess.run(
             args=[
                 "uv", "run", "datacontract", "import",
                 "--format", "sql",
@@ -41,7 +41,6 @@ class ModuleBuilder:
             check=True,
         )
 
-        click.echo(message=result)
 
 
 
