@@ -30,7 +30,7 @@ class NexusPublisher:
         env["TWINE_PASSWORD"] = nexus_pass
         env["TWINE_REPOSITORY_URL"] = nexus_repo
 
-        result: subprocess.CompletedProcess = subprocess.run(
+        subprocess.run(
             args=[
                 "uv",
                 "run",
